PanBehavior<D> class

Inheritance
Annotations

Constructors

PanBehavior({PanningCompletedCallback? panningCompletedCallback})

Properties

desiredGestures → Set<GestureType>
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
panningCompletedCallback → PanningCompletedCallback?
Optional callback that is called when panning is completed.
final
role → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCommonBehavior() → PanBehavior<D>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateCommonBehavior(ChartBehavior commonBehavior) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
override